==> aws_pdk-0.23.9.tar.gz: package/infrastructure/projects/python/infrastructure-py-project.d.ts <==
import { CloudscapeReactTsWebsiteProject } from "../../../cloudscape-react-ts-website";
import { TypeSafeApiProject } from "../../../type-safe-api";
import { AwsCdkPythonApp } from "projen/lib/awscdk";
import { AwsCdkPythonAppOptions } from "./aws-cdk-py-app-options";
/**
 * Configuration options for the InfrastructurePyProject.
 */
export interface InfrastructurePyProjectOptions extends AwsCdkPythonAppOptions {
    /**
     * Stack name.
     *
     * @default infra-dev
     */
    readonly stackName?: string;
    /**
     * TypeSafeApi instance to use when setting up the initial project sample code.
     * @deprecated use typeSafeApis
     */
    readonly typeSafeApi?: TypeSafeApiProject;
    /**
     * CloudscapeReactTsWebsiteProject instance to use when setting up the initial project sample code.
     * @deprecated use cloudscapeReactTsWebsites
     */
    readonly cloudscapeReactTsWebsite?: CloudscapeReactTsWebsiteProject;
    /**
     * TypeSafeApi instances to use when setting up the initial project sample code.
     */
    readonly typeSafeApis?: TypeSafeApiProject[];
    /**
     * CloudscapeReactTsWebsiteProject instances to use when setting up the initial project sample code.
     */
    readonly cloudscapeReactTsWebsites?: CloudscapeReactTsWebsiteProject[];
}
/**
 * Synthesizes a Infrastructure Python Project.
 */
export declare class InfrastructurePyProject extends AwsCdkPythonApp {
    constructor(options: InfrastructurePyProjectOptions);
    private generateTypeSafeMustacheConfig;
    private capitalize;
    private emitSampleFiles;
}

==> aws_pdk-0.25.8.tar.gz: package/infrastructure/projects/python/infrastructure-py-project.d.ts <==
import { CloudscapeReactTsWebsiteProject } from "../../../cloudscape-react-ts-website";
import { TypeSafeApiProject } from "../../../type-safe-api";
import { AwsCdkPythonApp } from "projen/lib/awscdk";
import { AwsCdkPythonAppOptions } from "./aws-cdk-py-app-options";
import { DeploymentStage } from "../../components/deployment-stage";
/**
 * Configuration options for the InfrastructurePyProject.
 */
export interface InfrastructurePyProjectOptions extends AwsCdkPythonAppOptions {
    /**
     * Stack name.
     *
     * @default infra-dev
     */
    readonly stackName?: string;
    /**
     * List of deployment stages.
     */
    readonly stages?: DeploymentStage[];
    /**
     * Allow self sign up for the UserIdentity construct.
     *
     * @default - false
     */
    readonly allowSignup?: boolean;
    /**
     * TypeSafeApi instance to use when setting up the initial project sample code.
     * @deprecated use typeSafeApis
     */
    readonly typeSafeApi?: TypeSafeApiProject;
    /**
     * CloudscapeReactTsWebsiteProject instance to use when setting up the initial project sample code.
     * @deprecated use cloudscapeReactTsWebsites
     */
    readonly cloudscapeReactTsWebsite?: CloudscapeReactTsWebsiteProject;
    /**
     * TypeSafeApi instances to use when setting up the initial project sample code.
     */
    readonly typeSafeApis?: TypeSafeApiProject[];
    /**
     * CloudscapeReactTsWebsiteProject instances to use when setting up the initial project sample code.
     */
    readonly cloudscapeReactTsWebsites?: CloudscapeReactTsWebsiteProject[];
}
/**
 * Synthesizes a Infrastructure Python Project.
 */
export declare class InfrastructurePyProject extends AwsCdkPythonApp {
    constructor(options: InfrastructurePyProjectOptions);
    private generateTypeSafeMustacheConfig;
    private capitalize;
    private emitSampleFiles;
}
